@@ -102,7 +102,7 @@ class Domoticz(IPlugin):
 #				log.msg("jsonreq.result :  %s" % (jsonreq['result']))
 				for rt in jsonreq['result'] :
 					log.msg("*** jsonreq - NT - idx   :  %s" % (rt['idx']))
-					if int(rs['idx']) == rt['idx']:
+					if int(rs['idx']) == int(rt['idx']):
 						log.msg("**************************  jsonreq - idx   :  %s" % (rt['idx']))
 						log.msg("*********  jsonreq - batlevel   :  %s" % (rt['BatteryLevel']))
 						log.msg("*********  jsonreq - Temp   :  %s" % (rt['Temp']))
